@@ -139,6 +139,12 @@ int main(int, char *argv[])
 	                "'" + StreamedContents + "', "
 			"got '" + Readback + "'");
   }
+  catch (const sql_error &e)
+  {
+    cerr << "SQL error: " << e.what() << endl
+         << "Query was: '" << e.query() << "'" << endl;
+    return 1;
+  }
   catch (const exception &e)
   {
     cerr << "Exception: " << e.what() << endl;
